ALTER FUNCTION fonction1() OWNER TO rol1

ALTER VIEW v1 OWNER TO rol2

ALTER TABLE t1 OWNER TO rol3

ALTER SCHEMA schema1 OWNER TO rol4

ALTER OPERATOR CLASS public.ean13_ops USING btree OWNER TO postgres
